server

package
v0.0.0-...-dc0472d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Start

Start manages the HTTP server lifecycle with graceful shutdown This function blocks until the server shuts down or an error occurs.

func WebRouter

func WebRouter(svcEnv *config.ServiceEnvConfig, lgr logger.Logger, dbMgr mongodb.MongoManager) (*gin.Engine, error)

Types

type Server

type Server struct {
	Router *gin.Engine
}

Jump to